/**
 * OS Management Hub API
 * Use the OS Management Hub API to manage and monitor updates and patches for the operating system environments in your private data centers through a single management console. For more information, see [Overview of OS Management Hub](https://docs.cloud.oracle.com/iaas/osmh/doc/overview.htm).
Use the table of contents and search tool to explore the  OS Management Hub API.

 * OpenAPI spec version: 20220901
 *
 *
 * NOTE: This class is auto generated by OracleSDKGenerator.
 * Do not edit the class manually.
 *
 * Copyright (c) 2020, 2023, Oracle and/or its affiliates.  All rights reserved.
 * This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
 */
import * as model from "../model";
/**
 * Detailed information about an ManagementStation config
 */
export interface ManagementStation {
    /**
     * OCID for the ManagementStation config
     */
    "id": string;
    /**
     * OCID for the Instance associated with the Management Station.
     */
    "managedInstanceId"?: string;
    /**
     * The OCID of the tenancy containing the Management Station.
     */
    "compartmentId": string;
    /**
     * OCID of the Scheduled Job for mirror sync
     */
    "scheduledJobId"?: string;
    /**
     * OCID of the Profile associated with the Station
     */
    "profileId"?: string;
    /**
     * ManagementStation name
     */
    "displayName": string;
    /**
     * Details describing the ManagementStation config.
     */
    "description"?: string;
    /**
     * Name of the host
     */
    "hostname": string;
    /**
     * Current state of the mirroring
     */
    "overallState"?: model.OverallState;
    /**
     * A decimal number representing the completeness percentage Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "overallPercentage"?: number;
    /**
     * A decimal number representing the mirror capacity Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "mirrorCapacity"?: number;
    /**
     * A decimal number representing the total of repos Note: Numbers greater than Number.MAX_SAFE_INTEGER will result in rounding issues.
     */
    "totalMirrors"?: number;
    "mirrorSyncStatus"?: model.MirrorSyncStatus;
    "proxy": model.ProxyConfiguration;
    "mirror": model.MirrorConfiguration;
    /**
     * The current state of the Management Station config.
     */
    "lifecycleState"?: ManagementStation.LifecycleState;
    /**
     * Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: `{\"Department\": \"Finance\"}`
     *
     */
    "freeformTags"?: {
        [key: string]: string;
    };
    /**
     * Defined tags for this resource. Each key is predefined and scoped to a namespace.
     * For more information, see [Resource Tags](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm).
     * Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`
     *
     */
    "definedTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
    /**
     * System tags for this resource. Each key is predefined and scoped to a namespace.
     * Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`
     *
     */
    "systemTags"?: {
        [key: string]: {
            [key: string]: any;
        };
    };
}
export declare namespace ManagementStation {
    enum LifecycleState {
        Creating = "CREATING",
        Updating = "UPDATING",
        Active = "ACTIVE",
        Deleting = "DELETING",
        Deleted = "DELETED",
        Failed = "FAILED",
        /**
         * This value is used if a service returns a value for this enum that is not recognized by this
         * version of the SDK.
         */
        UnknownValue = "UNKNOWN_VALUE"
    }
    function getJsonObj(obj: ManagementStation): object;
    function getDeserializedJsonObj(obj: ManagementStation): object;
}
